---------------------------------------------------
-- [v1.01.00] Make sure we have nUI tables
---------------------------------------------------
if not nUI_InfoPanels then nUI_InfoPanels = {}; end

----------------------------------------------------------------
-- [v1.01.00] Localized Functions and Tables to speed things up
----------------------------------------------------------------
local _L = nUI_InfoPanel_Professions_L;

---------------------------------------------------
-- [v1.01.00] Allocation of the Window ID (unique)
---------------------------------------------------
nUI_INFOMODE_Professions  = 40;
nUI_INFOPANEL_Professions = "nUI_InfoPanel_Professions";

---------------------------------------------------
-- [v1.01.00] Set the Default values for the Infopanel
---------------------------------------------------
nUI_InfoPanels[nUI_INFOPANEL_Professions ] =
{	
	enabled   = true,
	desc      = _L["Info Panel Text"],             -- player friendly name/description of the panel
	label     = _L["Info Panel Label"],	       -- label to use on the panel selection button face
	rotation  = nUI_INFOMODE_Professions,            -- index or position this panel appears on/in when clicking the selector button
	full_size = true;                              -- this plugin requires the entire info panel port without the button bag
	
	options  =
	{
		enabled  = true,
	},
};

---------------------------------------------------
-- [v1.01.00] Set Plugin Values
---------------------------------------------------
local plugin    = CreateFrame( "Frame", nUI_INFOPANEL_Professions, nUI_Dashboard.Anchor );
plugin.active   = true;

---------------------------------------------------
-- [v1.01.00] Validate Addon is loaded
---------------------------------------------------
local function onProfessionsEvent()
	if event == "ADDON_LOADED" then
		Professions_CreateFrame();
		if ( not Professions.Frame ) then
			plugin.active = false;
		end
	end	
end

plugin:SetScript( "OnEvent", onProfessionsEvent );
plugin:RegisterEvent( "ADDON_LOADED" );

---------------------------------------------------
-- [v1.01.00] initPanel routine
---------------------------------------------------
plugin.initPanel = function( container, options )
	plugin.container = container;
	plugin.options   = options;
	Professions_CreateFrame(); -- FORCE INIT
	if options and options.enabled then
		plugin.setEnabled( true );
	end
end

---------------------------------------------------
-- [v1.01.00] sizeChanged routine
-- [v1.01.03] Changed name of addon frame so as not to clash
-- [v1.02.00] Resize and Reposition according to scale
---------------------------------------------------
plugin.sizeChanged = function( scale, height, width )
	local options  = plugin.options;
	plugin.scale = scale;

	-- Grab addon information and unlock frame for movement
	local ProfessionsFrame   = plugin.Professions;
	nUI_Movers:lockFrame( ProfessionsFrame, false, nil );
	
	-- Resize and Reposition according to scale and size of new container
	ProfessionsFrame:SetWidth( width ); 
	ProfessionsFrame:SetHeight( height ); 
	
	-- Center Buttons across the container
	local cellCount = #Professions.topButtons;
    local cellWidth = ( width / cellCount );
    local btnSize = cellWidth * 0.8;
    local btnGap = cellWidth * 0.1;
    local verticalOffsettop = height / 3; 
    local verticalOffsetmiddle = height / 50;
    local verticalOffsetbottom = height / 3;

    for i=1,cellCount do
        Professions.topButtons[i]:SetWidth( btnSize );
        Professions.topButtons[i]:SetHeight( btnSize );
        Professions.middleButtons[i]:SetWidth( btnSize );
        Professions.middleButtons[i]:SetHeight( btnSize );
        Professions.bottomButtons[i]:SetWidth( btnSize );
        Professions.bottomButtons[i]:SetHeight( btnSize );
    end
    
    local odd = ( cellCount % 2 ) == 1;
    local midwayLeft = nil;
    local midwayRight = nil;
    if ( odd ) then 
		midwayLeft = math.ceil( cellCount / 2 );
	else
		midwayLeft = math.floor( cellCount / 2 );
		midwayRight = midwayLeft + 1;
	end

	-- Reposition top Buttons and Fontstrings
	if ( not midwayRight ) then
		Professions.topButtons[midwayLeft]:SetPoint( "CENTER", plugin.container, "CENTER", btnGap/2, verticalOffsettop);
		Professions.middleButtons[midwayLeft]:SetPoint( "CENTER", plugin.container, "CENTER", btnGap/2, verticalOffsetmiddle);
		Professions.bottomButtons[midwayLeft]:SetPoint( "CENTER", plugin.container, "CENTER", btnGap/2, -verticalOffsetbottom);
	else
	    	Professions.topButtons[midwayLeft]:SetPoint( "RIGHT", plugin.container, "CENTER", -btnGap/2, verticalOffsettop );
		Professions.topButtons[midwayRight]:SetPoint( "LEFT", plugin.container, "CENTER", btnGap/2, verticalOffsettop );
	    	Professions.middleButtons[midwayLeft]:SetPoint( "RIGHT", plugin.container, "CENTER", -btnGap/2, verticalOffsetmiddle );
		Professions.middleButtons[midwayRight]:SetPoint( "LEFT", plugin.container, "CENTER", btnGap/2, verticalOffsetmiddle );
	    	Professions.bottomButtons[midwayLeft]:SetPoint( "RIGHT", plugin.container, "CENTER", -btnGap/2, -verticalOffsetbottom );
		Professions.bottomButtons[midwayRight]:SetPoint( "LEFT", plugin.container, "CENTER", btnGap/2, -verticalOffsetbottom );
	end
	for i = 1, midwayLeft - 1 do	
		Professions.topButtons[i]:SetPoint( "RIGHT", Professions.topButtons[i+1], "LEFT", -btnGap, 0 );
		Professions.middleButtons[i]:SetPoint( "RIGHT", Professions.middleButtons[i+1], "LEFT", -btnGap, 0 );
		Professions.bottomButtons[i]:SetPoint( "RIGHT", Professions.bottomButtons[i+1], "LEFT", -btnGap, 0 );
	end
	for i = midwayLeft + 1, cellCount do	
		Professions.topButtons[i]:SetPoint( "LEFT", Professions.topButtons[i-1], "RIGHT", btnGap, 0 );
		Professions.middleButtons[i]:SetPoint( "LEFT", Professions.middleButtons[i-1], "RIGHT", btnGap, 0 );
		Professions.bottomButtons[i]:SetPoint( "LEFT", Professions.bottomButtons[i-1], "RIGHT", btnGap, 0 );
	end	
	
	-- Lock addon frame for movement
	nUI_Movers:lockFrame( ProfessionsFrame, true, nil );
end
---------------------------------------------------
-- [v1.01.00] Validate Enable Status
---------------------------------------------------
plugin.setEnabled = function( enabled )
	if plugin.enabled ~= enabled then
		plugin.enabled = enabled;
		if not enabled then
			local Professions = plugin.Professions;
			if Professions.saved_parent then
				nUI_Movers:lockFrame( Professions, false, nil );
				Professions:SetParent( Professions.saved_parent );
				Professions:SetBackdropBorderColor( Professions.border_color );
				Professions:SetBackdropColor( Professions.backdrop_color );
			end
		else
			local Professions = Professions.Frame;
			plugin.Professions = Professions;
			if not Professions.saved_parent then
				Professions.saved_parent   = Professions:GetParent();
				Professions.border_color   = Professions:GetBackdropBorderColor();
				Professions.backdrop_color = Professions:GetBackdropColor();
			end
			Professions:SetParent( plugin.container );
			Professions:SetPoint( "TOPLEFT", plugin.container, "TOPLEFT", 5, 5 );
			Professions:SetPoint( "BOTTOMRIGHT", plugin.container, "BOTTOMRIGHT", -5, -5 );
			Professions:SetFrameStrata( plugin.container:GetFrameStrata() );
			Professions:SetFrameLevel( plugin.container:GetFrameLevel()+1 );
			Professions:SetBackdropBorderColor( 0, 0, 0, 0 );
			Professions:SetBackdropColor( 0, 0, 0, 0 );
			
			nUI_Movers:lockFrame( Professions, true, nil );
		end				
	end			
end

---------------------------------------------------
-- [v1.01.00] setSelected routine
---------------------------------------------------
plugin.setSelected = function( selected )
	if selected ~= plugin.selected then
		plugin.selected = selected;
		if selected then
		else
		end
	end
end
